@@ -15,6 +15,14 @@ from stignore_agent.helpers import load_stignore_file, stignore_actions, load_ac
 app = Flask("stignore-agent")
 
 
+@app.after_request
+def after_request(response):
+    """Apply extra CORS header"""
+    headers = response.headers
+    headers["Access-Control-Allow-Origin"] = "*"
+    return response
+
+
 @app.route("/")
 def info_page():
     """Basic info page for users discovering this through their browser"""
@@ -32,7 +40,7 @@ def favicon():
     return send_from_directory("static/img", "favicon.ico")
 
 
-@app.route("/api/v1/types")
+@app.route("/api/v1/discover")
 def list_content_types():
     """Returns all configured content type folders"""
     folders = current_app.config["folders"]
@@ -40,7 +48,7 @@ def list_content_types():
     return jsonify(
         {
             "ok": True,
-            "content_types": list(folders.keys()),
+            "content_types": list({"name": name} for name in folders.keys())
         }
     )
 
